HOWTOs
******

This section contains practical **how-to guides**, instructions, and tutorials.
These are intended to illustrate and demonstrate how to work with TDC-compliant data and metadata, and develop code and other tools process such (meta)data.

In contrast, the :doc:`/standards` are *prescriptive*.
Put another way, a HOWTO shows *just one possible or suggested* way to comply with the standards.

.. toctree::
   :maxdepth: 1

   metadata
